==> xkeycaps_2.42.orig.tar.gz: xkeycaps-2.42/kbds/linux-omni102-map.h <==
/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1997
 *  Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the default keymap of a the Northgate OmniKey 102P
 * keyboard model (part number: KYBD102P; vendor code: 20017; rev 1.0.)
 * By Jeffrey Templon <templon@studbolt.physast.uga.edu>.
 */

#ifndef  XK_ISO_Left_Tab
# define XK_ISO_Left_Tab 0xFE20
#endif
#ifndef  XK_KP_Begin
# define XK_KP_Begin	0xFF9D
#endif

static const struct default_keycode_map linux_omni102_map [] = {
  {   9, 0,             { XK_Escape }},
  {  10, 0,             { XK_1,   XK_exclam }},
  {  11, 0,             { XK_2,   XK_at }},
  {  12, 0,             { XK_3,   XK_numbersign }},
  {  13, 0,             { XK_4,   XK_dollar }},
  {  14, 0,             { XK_5,   XK_percent }},
  {  15, 0,             { XK_6,   XK_asciicircum }},
  {  16, 0,             { XK_7,   XK_ampersand }},
  {  17, 0,             { XK_8,   XK_asterisk }},
  {  18, 0,             { XK_9,   XK_parenleft }},
  {  19, 0,             { XK_0,   XK_parenright }},
  {  20, 0,             { XK_minus,       XK_underscore }},
  {  21, 0,             { XK_equal,       XK_plus }},
  {  22, 0,             { XK_BackSpace }},
  {  23, 0,             { XK_Tab, XK_ISO_Left_Tab }},
  {  24, 0,             { XK_q,   XK_Q }},
  {  25, 0,             { XK_w,   XK_W }},
  {  26, 0,             { XK_e,   XK_E }},
  {  27, 0,             { XK_r,   XK_R }},
  {  28, 0,             { XK_t,   XK_T }},
  {  29, 0,             { XK_y,   XK_Y }},
  {  30, 0,             { XK_u,   XK_U }},
  {  31, 0,             { XK_i,   XK_I }},
  {  32, 0,             { XK_o,   XK_O }},
  {  33, 0,             { XK_p,   XK_P }},
  {  34, 0,             { XK_bracketleft, XK_braceleft }},
  {  35, 0,             { XK_bracketright,        XK_braceright }},
  {  36, 0,             { XK_Return }},
  {  37, ControlMask,   { XK_Control_L }},
  {  38, 0,             { XK_a,   XK_A }},
  {  39, 0,             { XK_s,   XK_S }},
  {  40, 0,             { XK_d,   XK_D }},
  {  41, 0,             { XK_f,   XK_F }},
  {  42, 0,             { XK_g,   XK_G }},
  {  43, 0,             { XK_h,   XK_H }},
  {  44, 0,             { XK_j,   XK_J }},
  {  45, 0,             { XK_k,   XK_K }},
  {  46, 0,             { XK_l,   XK_L }},
  {  47, 0,             { XK_semicolon,   XK_colon }},
  {  48, 0,             { XK_apostrophe,  XK_quotedbl }},
  {  49, 0,             { XK_grave,       XK_asciitilde }},
  {  50, ShiftMask,     { XK_Shift_L }},
  {  51, 0,             { XK_backslash,   XK_bar }},
  {  52, 0,             { XK_z,   XK_Z }},
  {  53, 0,             { XK_x,   XK_X }},
  {  54, 0,             { XK_c,   XK_C }},
  {  55, 0,             { XK_v,   XK_V }},
  {  56, 0,             { XK_b,   XK_B }},
  {  57, 0,             { XK_n,   XK_N }},
  {  58, 0,             { XK_m,   XK_M }},
  {  59, 0,             { XK_comma,       XK_less }},
  {  60, 0,             { XK_period,      XK_greater }},
  {  61, 0,             { XK_slash,       XK_question }},
  {  62, ShiftMask,     { XK_Shift_R }},
  {  63, 0,             { XK_KP_Multiply }},
  {  64, Mod1Mask,      { XK_Alt_L,       XK_Meta_L }},
  {  65, 0,             { XK_space }},
  {  66, LockMask,      { XK_Caps_Lock }},
  {  67, 0,             { XK_F1 }},
  {  68, 0,             { XK_F2 }},
  {  69, 0,             { XK_F3 }},
  {  70, 0,             { XK_F4 }},
  {  71, 0,             { XK_F5 }},
  {  72, 0,             { XK_F6 }},
  {  73, 0,             { XK_F7 }},
  {  74, 0,             { XK_F8 }},
  {  75, 0,             { XK_F9 }},
  {  76, 0,             { XK_F10 }},
  {  77, Mod2Mask,      { XK_Num_Lock }},
  {  78, Mod3Mask,      { XK_Scroll_Lock }},
  {  79, 0,             { XK_KP_Home,     XK_KP_7 }},
  {  80, 0,             { XK_KP_Up,       XK_KP_8 }},
  {  81, 0,             { XK_KP_Prior,    XK_KP_9 }},
  {  82, 0,             { XK_KP_Subtract }},
  {  83, 0,             { XK_KP_Left,     XK_KP_4 }},
  {  84, 0,             { XK_KP_Begin,    XK_KP_5 }},
  {  85, 0,             { XK_KP_Right,    XK_KP_6 }},
  {  86, 0,             { XK_KP_Add }},
  {  87, 0,             { XK_KP_End,      XK_KP_1 }},
  {  88, 0,             { XK_KP_Down,     XK_KP_2 }},
  {  89, 0,             { XK_KP_Next,     XK_KP_3 }},
  {  90, 0,             { XK_KP_Insert,   XK_KP_0 }},
  {  91, 0,             { XK_KP_Delete,   XK_KP_Decimal }},
  {  95, 0,             { XK_F11 }},
  {  96, 0,             { XK_F12 }},
  {  97, 0,             { XK_Home }},
  {  98, 0,             { XK_Up }},
  {  99, 0,             { XK_Prior }},
  { 100, 0,             { XK_Left }},
  { 101, 0,		{ 0 }}, /* OmniKey - no keysym in default map */
  { 102, 0,             { XK_Right }},
  { 103, 0,             { XK_End }},
  { 104, 0,             { XK_Down }},
  { 105, 0,             { XK_Next }},
  { 106, 0,             { XK_Insert }},
  { 107, 0,             { XK_Delete }},
  { 108, 0,             { XK_KP_Enter }},
  { 109, ControlMask,   { XK_Control_R }},
  { 110, 0,             { XK_Pause,       XK_Break }},
  { 111, 0,             { XK_Print,       XK_Execute }},
  { 112, 0,             { XK_KP_Divide }},
  { 113, Mod1Mask,      { XK_Alt_R,       XK_Meta_R }}
  };

==> xkeycaps_2.43.orig.tar.gz: xkeycaps-2.43/kbds/linux-omni102-map.h <==
/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1997
 *  Jamie Zawinski <jwz@jwz.org>
 *
 * This file describes the default keymap of a the Northgate OmniKey 102P
 * keyboard model (part number: KYBD102P; vendor code: 20017; rev 1.0.)
 * By Jeffrey Templon <templon@studbolt.physast.uga.edu>.
 */

#ifndef XK_ISO_Left_Tab
# define XK_ISO_Left_Tab	0xFE20
#endif
#ifndef XK_KP_Begin
# define XK_KP_Begin		0xFF9D
#endif
#ifndef XK_KP_Delete
# define XK_KP_Delete		0xFF9F
#endif
#ifndef XK_KP_Down
# define XK_KP_Down		0xFF99
#endif
#ifndef XK_KP_End
# define XK_KP_End		0xFF9C
#endif
#ifndef XK_KP_Home
# define XK_KP_Home		0xFF95
#endif
#ifndef XK_KP_Insert
# define XK_KP_Insert		0xFF9E
#endif
#ifndef XK_KP_Left
# define XK_KP_Left		0xFF96
#endif
#ifndef XK_KP_Next
# define XK_KP_Next		0xFF9B
#endif
#ifndef XK_KP_Prior
# define XK_KP_Prior		0xFF9A
#endif
#ifndef XK_KP_Right
# define XK_KP_Right		0xFF98
#endif
#ifndef XK_KP_Up
# define XK_KP_Up		0xFF97
#endif

static const struct default_keycode_map linux_omni102_map [] = {
  {   9, 0,             { XK_Escape }},
  {  10, 0,             { XK_1,   XK_exclam }},
  {  11, 0,             { XK_2,   XK_at }},
  {  12, 0,             { XK_3,   XK_numbersign }},
  {  13, 0,             { XK_4,   XK_dollar }},
  {  14, 0,             { XK_5,   XK_percent }},
  {  15, 0,             { XK_6,   XK_asciicircum }},
  {  16, 0,             { XK_7,   XK_ampersand }},
  {  17, 0,             { XK_8,   XK_asterisk }},
  {  18, 0,             { XK_9,   XK_parenleft }},
  {  19, 0,             { XK_0,   XK_parenright }},
  {  20, 0,             { XK_minus,       XK_underscore }},
  {  21, 0,             { XK_equal,       XK_plus }},
  {  22, 0,             { XK_BackSpace }},
  {  23, 0,             { XK_Tab, XK_ISO_Left_Tab }},
  {  24, 0,             { XK_q,   XK_Q }},
  {  25, 0,             { XK_w,   XK_W }},
  {  26, 0,             { XK_e,   XK_E }},
  {  27, 0,             { XK_r,   XK_R }},
  {  28, 0,             { XK_t,   XK_T }},
  {  29, 0,             { XK_y,   XK_Y }},
  {  30, 0,             { XK_u,   XK_U }},
  {  31, 0,             { XK_i,   XK_I }},
  {  32, 0,             { XK_o,   XK_O }},
  {  33, 0,             { XK_p,   XK_P }},
  {  34, 0,             { XK_bracketleft, XK_braceleft }},
  {  35, 0,             { XK_bracketright,        XK_braceright }},
  {  36, 0,             { XK_Return }},
  {  37, ControlMask,   { XK_Control_L }},
  {  38, 0,             { XK_a,   XK_A }},
  {  39, 0,             { XK_s,   XK_S }},
  {  40, 0,             { XK_d,   XK_D }},
  {  41, 0,             { XK_f,   XK_F }},
  {  42, 0,             { XK_g,   XK_G }},
  {  43, 0,             { XK_h,   XK_H }},
  {  44, 0,             { XK_j,   XK_J }},
  {  45, 0,             { XK_k,   XK_K }},
  {  46, 0,             { XK_l,   XK_L }},
  {  47, 0,             { XK_semicolon,   XK_colon }},
  {  48, 0,             { XK_apostrophe,  XK_quotedbl }},
  {  49, 0,             { XK_grave,       XK_asciitilde }},
  {  50, ShiftMask,     { XK_Shift_L }},
  {  51, 0,             { XK_backslash,   XK_bar }},
  {  52, 0,             { XK_z,   XK_Z }},
  {  53, 0,             { XK_x,   XK_X }},
  {  54, 0,             { XK_c,   XK_C }},
  {  55, 0,             { XK_v,   XK_V }},
  {  56, 0,             { XK_b,   XK_B }},
  {  57, 0,             { XK_n,   XK_N }},
  {  58, 0,             { XK_m,   XK_M }},
  {  59, 0,             { XK_comma,       XK_less }},
  {  60, 0,             { XK_period,      XK_greater }},
  {  61, 0,             { XK_slash,       XK_question }},
  {  62, ShiftMask,     { XK_Shift_R }},
  {  63, 0,             { XK_KP_Multiply }},
  {  64, Mod1Mask,      { XK_Alt_L,       XK_Meta_L }},
  {  65, 0,             { XK_space }},
  {  66, LockMask,      { XK_Caps_Lock }},
  {  67, 0,             { XK_F1 }},
  {  68, 0,             { XK_F2 }},
  {  69, 0,             { XK_F3 }},
  {  70, 0,             { XK_F4 }},
  {  71, 0,             { XK_F5 }},
  {  72, 0,             { XK_F6 }},
  {  73, 0,             { XK_F7 }},
  {  74, 0,             { XK_F8 }},
  {  75, 0,             { XK_F9 }},
  {  76, 0,             { XK_F10 }},
  {  77, Mod2Mask,      { XK_Num_Lock }},
  {  78, Mod3Mask,      { XK_Scroll_Lock }},
  {  79, 0,             { XK_KP_Home,     XK_KP_7 }},
  {  80, 0,             { XK_KP_Up,       XK_KP_8 }},
  {  81, 0,             { XK_KP_Prior,    XK_KP_9 }},
  {  82, 0,             { XK_KP_Subtract }},
  {  83, 0,             { XK_KP_Left,     XK_KP_4 }},
  {  84, 0,             { XK_KP_Begin,    XK_KP_5 }},
  {  85, 0,             { XK_KP_Right,    XK_KP_6 }},
  {  86, 0,             { XK_KP_Add }},
  {  87, 0,             { XK_KP_End,      XK_KP_1 }},
  {  88, 0,             { XK_KP_Down,     XK_KP_2 }},
  {  89, 0,             { XK_KP_Next,     XK_KP_3 }},
  {  90, 0,             { XK_KP_Insert,   XK_KP_0 }},
  {  91, 0,             { XK_KP_Delete,   XK_KP_Decimal }},
  {  95, 0,             { XK_F11 }},
  {  96, 0,             { XK_F12 }},
  {  97, 0,             { XK_Home }},
  {  98, 0,             { XK_Up }},
  {  99, 0,             { XK_Prior }},
  { 100, 0,             { XK_Left }},
  { 101, 0,		{ 0 }}, /* OmniKey - no keysym in default map */
  { 102, 0,             { XK_Right }},
  { 103, 0,             { XK_End }},
  { 104, 0,             { XK_Down }},
  { 105, 0,             { XK_Next }},
  { 106, 0,             { XK_Insert }},
  { 107, 0,             { XK_Delete }},
  { 108, 0,             { XK_KP_Enter }},
  { 109, ControlMask,   { XK_Control_R }},
  { 110, 0,             { XK_Pause,       XK_Break }},
  { 111, 0,             { XK_Print,       XK_Execute }},
  { 112, 0,             { XK_KP_Divide }},
  { 113, Mod1Mask,      { XK_Alt_R,       XK_Meta_R }}
  };
